@@ -1,4 +1,4 @@
-package File::Data;           
+package File::Data;
 
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ use FileHandle;
 # use Tie::File; # <- todo
 # use File::stat;
 use vars qw(@ISA $VERSION $AUTOLOAD);
-$VERSION = do { my @r = (q$Revision: 1.15 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; 
+$VERSION = do { my @r = (q$Revision: 1.17 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $| = 1;
 
 =head1 NAME
@@ -20,7 +20,7 @@ File::Data - interface to file data
 =head1 DESCRIPTION
 
 Wraps all the accessing of a file into a convenient set of calls for
-reading and writing data, including a simple regex interface.  
+reading and writing data, including a simple regex interface.
 
 Note that the file needs to exist prior to using this module!
 
@@ -53,7 +53,7 @@ Or, perhaps more seriously :-}
 	my $o_sgm = File::Data->new('./sgmlfile');
 
 	print "new SGML data: ".$o_sgm->REPLACE(
-		'\<\s*((?i)tag)\s*\>\s*((?s).*)\s*\<\s*((?i)\s*\/\s*tag)\s*\>', 
+		'\<\s*((?i)tag)\s*\>\s*((?s).*)\s*\<\s*((?i)\s*\/\s*tag)\s*\>',
 		qq|<tag>key="val"</tag>|,		
 	) if $o_sgm;
 
@@ -122,7 +122,7 @@ one.
 
 # Methods we like:
 # ================================================================
-# 
+#
 my @_METHODS = qw(append insert prepend read replace return search write);
 my $_METHODS = join('|', @_METHODS);
 
@@ -157,7 +157,7 @@ to the B<new()> method
 sub new {
 	my $class = shift;
 	my $file  = shift;
-	my $perms = shift || $File::Data::PERMISSIONS; 
+	my $perms = shift || $File::Data::PERMISSIONS;
 	my $h_err = shift || {};
 
 	my $self = bless({
@@ -208,7 +208,7 @@ read
 
 =cut
 
-sub _read { # 
+sub _read { #
 	my $self = shift;
 
 	my $FH = $self->_fh;
@@ -250,7 +250,7 @@ sub WRITE {
 	return ($File::Data::REFERENCE) ? \@ret : @ret;
 };
 
-sub _write { # 
+sub _write { #
 	my $self = shift;
 	my @ret  = ();
 
@@ -396,7 +396,7 @@ Note - you must use capturing parentheses for this to work!
 
 sub SEARCH {
 	my $self   = shift;
-	my $search = shift; 
+	my $search = shift;
 	my @ret    = ();
 
 	$self->_enter('search');
@@ -434,7 +434,7 @@ sub SEARCH {
 	return ($File::Data::REFERENCE) ? \@ret : @ret;
 }
 
-=item replace 
+=item replace
 
 Replace data in a 'search and replace' manner, returns the final data.
 
@@ -446,9 +446,9 @@ Replace data in a 'search and replace' manner, returns the final data.
 		q|\<a href=(['"])([^$1]+)?$1| => q|'my.sales.com'|,
 	);
 
-This is B<simple>, in that you can do almost anything in the B<search> side, 
-but the B<replace> side is a bit more restricted, as we can't effect the 
-replacement modifiers on the fly.  
+This is B<simple>, in that you can do almost anything in the B<search> side,
+but the B<replace> side is a bit more restricted, as we can't effect the
+replacement modifiers on the fly.
 
 If you really need this, perhaps B<(?{})> can help?
 
@@ -475,7 +475,7 @@ sub REPLACE {
 				my $data = <$FH>; $/ = $orig;
 				$self->_debug("initial ($data)") if $File::Data::DEBUG;
 				if (($i_cnt = ($data =~ s/$search/$replace/g))) {
-					@ret = $data; 
+					@ret = $data;
 				} else {
 					print "unable($i_cnt) to search($search) and replace($replace)\n";
 				}
@@ -493,7 +493,7 @@ sub REPLACE {
                 $FH->seek(0, 0);
                 $FH->truncate(0);
                 $FH->seek(0, 0);
-                @ret = $self->_write(@ret); 
+                @ret = $self->_write(@ret);
             }
 			if (!($i_cnt >= 1)) {
 				$self->_debug("nonfulfilled search($search) and replace($replace) in file($file)");
@@ -523,7 +523,7 @@ sub RETURN {
 	my $self = shift;
 	my $call = uc(shift) || $self->_var('last');
 
-	if ((defined($self->{'_var'}{$call}) && 
+	if ((defined($self->{'_var'}{$call}) &&
 		     ref($self->{'_var'}{$call}) eq 'ARRAY'
 	)) {
 		return @{$self->_var($call)};
@@ -542,12 +542,12 @@ placeholder - unsupported
 sub create {
 	my $self = shift;
 
-	$self->_error("unsupported call: __FILE__(@_)"); 
+	$self->_error("unsupported call: __FILE__(@_)");
 
 	return ();
 }
 
-=item delete 
+=item delete
 
 placeholder - unsupported
 
@@ -556,12 +556,12 @@ placeholder - unsupported
 sub delete {
 	my $self = shift;
 
-	$self->_error("unsupported call: __FILE__(@_)"); 
+	$self->_error("unsupported call: __FILE__(@_)");
 
 	return ();
 }
 
-=item close 
+=item close
 
 Close the file
 
@@ -576,7 +576,7 @@ sub close {
 }
 
 
-=item info 
+=item info
 
 placeholder - unsupported
 
@@ -617,7 +617,7 @@ sub dummy {
 	$self->_debug('in: '.Dumper(\%args)) if $File::Data::DEBUG;
 
 	# if ($self->_writable) {
-	# 
+	#
 	# $FH->seek(0, 2);
 	# }
 
@@ -652,7 +652,7 @@ Alternatively  set to a regex of any of the prime methods to debug them individu
 =cut
 
 $File::Data::DEBUG ||= $ENV{'File_Data_DEBUG'} || 0;
-# $File::Data::DEBUG = 1; # 
+# $File::Data::DEBUG = 1; #
 
 =item $File::Data::FATAL
 
@@ -670,12 +670,8 @@ $File::Data::FATAL ||= $ENV{'File_Data_FATAL'} || 0;
 
 Will return a reference, not a list, useful with large files.
 
-Default is 0, ie; methods normally returns a list.
-
-Hopefully future versions of perl may return a reference if you request one, 
-but as this is not supported generically yet, nor do we, so we require the 
-variable to be set.  There may be an argument to make this a reference by 
-default, feedback will decide.
+Default is 0, ie; methods normally returns a list.  There may be an argument to
+make returns work with references by default, feedback will decide.
 
 	$File::Data::REFERENCE = 1;
 
@@ -701,7 +697,7 @@ $File::Data::SILENT ||= $ENV{'File_Data_SILENT'} || 0;
 
 =item $File::Data::STRING
 
-Where regex's are used, default behaviour is to treate the entire file as a 
+Where regex's are used, default behaviour is to treate the entire file as a
 single scalar string, so that, for example, B<(?ms:...)> matches are effective.
 
 Unset if you don't want this behaviour.
@@ -752,7 +748,7 @@ $File::Data::PERMISSIONS ||= $ENV{'File_Data_PERMISSIONS'} || '+<';
 
 =item AUTOLOAD
 
-Any unrecognised function will be passed to the FileHandle object for final 
+Any unrecognised function will be passed to the FileHandle object for final
 consideration, behaviour is then effectively 'o_dat ISA FileHandle'.
 
 	$o_dat->truncate;
@@ -765,17 +761,17 @@ sub AUTOLOAD {
 
     my $meth = $AUTOLOAD;
 	$meth =~ s/.+::([^:]+)$/$1/;
- 
+
     if ($meth =~ /^($_METHODS)$/io) { 		# convenience
 		$self->_debug("rerouting: $meth(@_)");
-        return $self->do(uc($meth), @_);					# <- 
-        # return $self->do(lc($meth), @_); 
+        return $self->do(uc($meth), @_);					# <-
+        # return $self->do(lc($meth), @_);
     } else { 								# or fallback
 		my $FH = $self->_fh;
 		if ($FH->can($meth)) {
 			return $FH->$meth(@_);							# <-
 		} else {									
-			$DB::single=2; # 
+			$DB::single=2; #
 			return $self->_error("no such method($meth)!"); # <-
 		}
     }
@@ -817,10 +813,10 @@ Typical construction examples:
 
 =item error
 
-Failure is indicated by an error routine being called, this will print 
-out any error to STDERR, unless warnings are declared fatal, in which 
-case we croak.  You can register your own error handlers for any method 
-mentioned in the L<METHOD> section of this document, in addition is a 
+Failure is indicated by an error routine being called, this will print
+out any error to STDERR, unless warnings are declared fatal, in which
+case we croak.  You can register your own error handlers for any method
+mentioned in the L<METHOD> section of this document, in addition is a
 special B<init> call for initial file opening and general setting up.
 
 Create a read-write object with a callback for all errors:
@@ -855,10 +851,10 @@ And (very non-obfuscated)
       append(shift(@x).\"\n\")->   \
       prepend(shift(@x).\"\n\")->  \
       insert(2, shift(@x).\"\n\")->\
-    READ;" 
+    READ;"
   >
 
-If you still have problems, mail me the output of 
+If you still have problems, mail me the output of
 		
 	make test TEST_VERBOSE=1
 
@@ -892,7 +888,7 @@ sub _var {
 		$self->_error("No such key($key) val($val)!");
 	} else {
 		if (defined($val)) {
-			$self->{'_var'}{$key} = $val; 
+			$self->{'_var'}{$key} = $val;
 			# {"$File::Data::$key"} = $val;
 			$self->_debug("set key($key) => val($val)");
 		}
@@ -922,7 +918,7 @@ sub _debug {
 }
 
 # Return dumped env and object B<key> and B<values>
-# 
+#
 #	print $o_dat->_vars;
 
 sub _vars {
@@ -958,30 +954,30 @@ sub _err {
 # handlers in.
 
 sub _error {
-	my $self = shift; 
+	my $self = shift;
 	my @err  = @_;
 	my @ret  = ();
 
-	my $state = $self->_var('state'); 
-	my $c_ref = $self->_err($state ); 
-	my $error = $self->_var('error'); 
+	my $state = $self->_var('state');
+	my $c_ref = $self->_err($state );
+	my $error = $self->_var('error');
 	unshift(@err, "$state ERROR: ");
-	my $ref   = $self->_var('errors', join("\n", @err)); 
+	my $ref   = $self->_var('errors', join("\n", @err));
 
 	# $self->_debug($self->_vars) if $File::Data::DEBUG;
 
 		if (ref($c_ref) eq 'CODE') {
 			eval { @ret = &$c_ref(@err) };
 			if ($@) {
-			$File::Data::FATAL >= 1 
+			$File::Data::FATAL >= 1
 				? croak("$0 failed: $c_ref(@err)")
 				: carp("$0 failed: $c_ref(@err)")
 			;
 		}
-		} elsif (ref($c_ref) && $c_ref->can($state)) { 
+		} elsif (ref($c_ref) && $c_ref->can($state)) {
 			eval { @ret = $c_ref->$state(@err) };
 			if ($@) {
-			$File::Data::FATAL >= 1 
+			$File::Data::FATAL >= 1
 				? croak("$0 failed: $c_ref(@err)")
 				: carp("$0 failed: $c_ref(@err)")
 			;
@@ -992,7 +988,7 @@ sub _error {
 			}
 		}
 
-	return (); # 
+	return (); #
 }
 
 #	my $file = $o_dat->_mapfile($filename);
@@ -1006,12 +1002,12 @@ sub _mapfile {
 
 	unless ($file =~ /\w+/o) {
 		$file = '';
-		$self->_error("inappropriate filename($file)"); 
+		$self->_error("inappropriate filename($file)");
 	} else {
 		my $xfile = $self->_var('filename') || '';
 		if ($xfile =~ /.+/o) {
 			$file = '';
-			$self->_error("can't reuse ".ref($self)." object($xfile) for another file($file)"); 
+			$self->_error("can't reuse ".ref($self)." object($xfile) for another file($file)");
 		}
 	}
 
@@ -1098,14 +1094,14 @@ sub _leave {
 
 # Get and set B<FileHandle>.  Returns undef otherwise.
 #
-#	my $FH = $o_dat->_fh($FH); 
+#	my $FH = $o_dat->_fh($FH);
 
 sub _fh {
 	my $self = shift;
 	my $arg  = shift;
 
 	my $FH = (defined($arg)
-		? $self->_var('filehandle', $arg) 
+		? $self->_var('filehandle', $arg)
 		: $self->_var('filehandle')
 	);
 	$self->_error("no filehandle($FH)") unless $FH;
@@ -1121,11 +1117,11 @@ sub _fh {
 #	0 = failure
 
 # Setup object, open a file, with permissions.
-# 
+#
 #	my $i_ok = $o_dat->_init( $file, $perm, $h_errs );
 
 sub _init {
-	my $self = shift; 
+	my $self = shift;
 	my $file = shift;
 	my $perm = shift;
 	my $h_err= shift;
@@ -1139,7 +1135,7 @@ sub _init {
 	$h_err = $self->_mapperrs($h_err) if $file; # if $perm
 
 	if ($file) { # unless $h_err
-		$i_ok = $self->_check_access($file, $perm); 
+		$i_ok = $self->_check_access($file, $perm);
 		if ($i_ok == 1) {
 			$file = $self->_var('filename', $file);
 			$perm = $self->_var('permissions', $perm);
@@ -1219,7 +1215,7 @@ sub _open {
 		$FH = $self->_fh($FH);
 		if ($FH) {
 			$i_ok++;
-			$i_ok = $self->_lock(); # if $self->_writable; 
+			$i_ok = $self->_lock(); # if $self->_writable;
 		}
 		$self->_debug("FH($FH) => i_ok($i_ok)");
 	}
@@ -1309,7 +1305,7 @@ sub _writable {
 	if ($i_ok != 1) {
 		my $file  = $self->_var('filename');
 		my $perms = $self->_var('permissions');
-		$self->_debug("$file not writable($i_ok) with permissions($perms)"); 
+		$self->_debug("$file not writable($i_ok) with permissions($perms)");
 	}
 
 	return $i_ok;
@@ -1344,7 +1340,7 @@ sub DO {
 	my $self = shift;
 	my $call = shift;
 	my @res  = ();
-	
+
 	$self->_enter('do');
 	$self->_debug('in: '.Dumper([$call, @_])) if $File::Data::DEBUG;
 
@@ -1365,7 +1361,7 @@ sub DO {
 
 sub do {
 	my $self = shift;
-	
+
 	$self->DO(@_);
 
 	return $self;
